@@ -1,5 +1,5 @@
 import click
-from app import aitest_application
+from app.aitest_application import *
 
 
 @click.group()
@@ -16,6 +16,6 @@ def main():
     """
 
 #adding subcommands 
-main.add_command(aitest_application.configure)
-main.add_command(aitest_application.run)
-main.add_command(aitest_application.status)
+main.add_command(configure)
+main.add_command(run)
+main.add_command(status)
