@@ -166,8 +166,11 @@ def run(testrun_id, git_pass, wait_time):
                 base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
                 status_res =requests.get(base_url,headers=headers)
                 status_test_data=status_res.json()
-                body=json.loads(status_test_data['body'])
-                test_status = body['testrun_status'] 
+                if status_test_data['statusCode'] == 200:
+                    body=json.loads(status_test_data['body'])
+                    test_status = body['testrun_status'] 
+                else:
+                    test_status = ""
                 if test_status=="completed":
                     testrun_status_details=body['testrun_status_details']
                     table = PrettyTable(["browser_name", "browser_version","test run result id", "status", "time taken"])
@@ -274,4 +277,3 @@ def status(testrun_id):
     else: 
         click.echo(f"{fail_count} test cases from this testrun have failed. Please refer above table for more details.")
         exit(1)   
-
